@@ -15,10 +15,10 @@ test_that("PipeOpFilter", {
 
   expect_equal(po$id, mlr3filters::FilterVariance$new()$id)
 
-  expect_error(po$train(list(task)), "Exactly one of 'nfeat', 'frac', 'cutoff' must be given.*none")
+  expect_error(po$train(list(task)), "Exactly one of 'nfeat', 'frac', 'cutoff', or 'permuted' must be given.*none")
 
   po$param_set$values = list(filter.nfeat = 1, filter.frac = 1, na.rm = TRUE)
-  expect_error(po$train(list(task)), "Exactly one of 'nfeat', 'frac', 'cutoff' must be given.*nfeat, frac")
+  expect_error(po$train(list(task)), "Exactly one of 'nfeat', 'frac', 'cutoff', or 'permuted' must be given.*nfeat, frac")
 
   po$param_set$values = list(filter.nfeat = 1, na.rm = TRUE)
 
@@ -49,7 +49,7 @@ test_that("PipeOpFilter parameters", {
 
   po = PipeOpFilter$new(mlr3filters::FilterVariance$new())
 
-  expect_set_equal(c("filter.nfeat", "filter.frac", "filter.cutoff"),
+  expect_set_equal(c("filter.nfeat", "filter.frac", "filter.cutoff", "filter.permuted"),
     grep("^filter\\.", names(po$param_set$params), value = TRUE))
 
   po = po$clone(deep = TRUE)  # cloning often breaks param connection
@@ -61,3 +61,31 @@ test_that("PipeOpFilter parameters", {
   expect_equal(po$filter$param_set$values$na.rm, TRUE)
 
 })
+
+
+test_that("PipeFilter permuted", {
+  set.seed(1)
+  N = 50
+  task = tgen("2dnormals")$generate(N)
+
+  po = po("filter", filter = mlr3filters::FilterAUC$new(), filter.permuted = 1)
+  out = po$train(list(task))[[1]]
+  expect_equal(out$feature_names, c("x1", "x2"))
+
+  task$cbind(data.frame(foo = runif(N), bar = runif(N)))
+  out = po$train(list(task))[[1]]
+  expect_equal(out$feature_names, c("x1", "x2"))
+
+  po = po("filter", filter = mlr3filters::FilterAUC$new(), filter.permuted = 2)
+  out = po$train(list(task))[[1]]
+  expect_equal(out$feature_names, c("x1", "x2"))
+
+  po = po("filter", filter = mlr3filters::FilterAUC$new(), filter.permuted = 100)
+  out = po$train(list(task))[[1]]
+  expect_equal(out$feature_names, task$feature_names)
+
+  task$select(setdiff(task$feature_names, c("x1", "x2")))
+  po = po("filter", filter = mlr3filters::FilterAUC$new(), filter.permuted = 1)
+  out = po$train(list(task))[[1]]
+  expect_equal(out$feature_names, character())
+})
